import argparse
import logging

import yaml

from . import db
from . import action
from . import config
from .utils import UserException

def main():
    parser = argparse.ArgumentParser(description='Higgins CLI')
    parser.add_argument('action', help='init, trigger, build or serve', nargs=1)
    parser.add_argument('--host', help='Host to listen to')
    parser.add_argument('--port', help='Port to listen to', type=int)
    args = parser.parse_args()

    cli_action = args.action[0]
    if not hasattr(action, 'do_' + cli_action):
        exit('Unkown action "%s"' % cli_action)

    # Init config
    config.read_config(cli_args=args)


    # logging.getLogger('sqlalchemy.engine').setLevel(logging.INFO)

    # Initialize context
    db.Context(config.DB_URI, echo=False)
    # Execute action
    try:
        res = getattr(action, 'do_' + cli_action)()
    except UserException, e:
        logging.error(e)

    if res:
        print yaml.safe_dump(res, default_flow_style=False)

if __name__ == '__main__':
    main()
