from collections import defaultdict
import json
import logging
import os

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger('config')

DOT_DIR = '.mt'
CONFIG_FILE = os.path.join(DOT_DIR, 'config.json')
BUILD_DIR = os.path.join(DOT_DIR, 'builds')
TEMPLATE_DIR = os.path.join(DOT_DIR, 'template')
STATIC_DIR = os.path.join(DOT_DIR, 'static')
DB_URI = 'sqlite:///' + DOT_DIR + '/db.sqlite'
CONFIG = None

def read_config(config_file=None, cli_args=None):
    global CONFIG, CONFIG_FILE, CLI_ARGS
    if CONFIG is not None:
        raise Exception('Config is already initialized')

    CLI_ARGS = cli_args

    if config_file is not None:
        CONFIG_FILE = config_file

    if not os.path.exists(CONFIG_FILE):
        logger.debug('Config file "%s" not found' % CONFIG_FILE)
        return

    with open(CONFIG_FILE) as fh:
        content = json.load(fh)

    by_depth = defaultdict(list)
    for key in content:
        by_depth[key.count('.')].append(key)

    for depth in sorted(by_depth)[1:]:
        for key in by_depth[depth]:
            parts = key.split('.')
            root = '.'.join(parts[:depth])
            parent = content.get(root, {})
            new_value = parent.copy()
            new_value.update(content[key])
            content[key] = new_value

    CONFIG = content

def save(data):
    with open(CONFIG_FILE, 'w') as fh:
        json.dump(data, fh, indent=4)

def get(name, default=None):
    return CONFIG.get(name, default)

def cli(name):
    return getattr(CLI_ARGS, name)
